import { __decorate } from 'tslib';
import { ɵɵdefineInjectable, Injectable, EventEmitter, Renderer2, Input, Output, Component, Pipe, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

let DropdownService = class DropdownService {
    constructor() { }
};
DropdownService.ɵprov = ɵɵdefineInjectable({ factory: function DropdownService_Factory() { return new DropdownService(); }, token: DropdownService, providedIn: "root" });
DropdownService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], DropdownService);

let DropdownComponent = class DropdownComponent {
    constructor(renderer) {
        this.renderer = renderer;
        this.dropdownList = [];
        this.selectedUnit = '';
        this.selectedDropdown = new EventEmitter();
        this.sCurveDropdown = false;
        this.menuBtnClick = false;
        this.dropdownSelect = '';
        this.dropdownWidth = 100;
        this.renderer.listen('window', 'click', (e) => {
            if (!this.menuBtnClick) {
                this.sCurveDropdown = false;
            }
            this.menuBtnClick = false;
        });
    }
    ngOnInit() {
    }
    ngOnChanges(changes) {
        if (this.selectedUnit && this.dropdownList.includes(this.selectedUnit)) {
            // this.dropdownSelect = this.selectedUnit;
            this.unitNameSelect(this.selectedUnit);
        }
        else {
            // this.dropdownSelect = this.dropdownList[0];
            this.unitNameSelect(this.dropdownList[0]);
        }
    }
    preventCloseOnClick() {
        this.menuBtnClick = true;
    }
    dropdownShow() {
        this.sCurveDropdown = !this.sCurveDropdown;
    }
    unitNameSelect(unitName) {
        this.dropdownSelect = unitName;
        if (this.dropdownSelect) {
            this.selectedDropdown.emit(this.dropdownSelect);
        }
        let number = 0;
        this.dropdownList.forEach(element => {
            if (number < element.length) {
                number = element.length;
            }
        });
        let width = number * 12;
        if (this.dropdownWidth < width) {
            this.dropdownWidth = width;
        }
        this.sCurveDropdown = false;
    }
};
DropdownComponent.ctorParameters = () => [
    { type: Renderer2 }
];
__decorate([
    Input()
], DropdownComponent.prototype, "dropdownList", void 0);
__decorate([
    Input()
], DropdownComponent.prototype, "selectedUnit", void 0);
__decorate([
    Output()
], DropdownComponent.prototype, "selectedDropdown", void 0);
DropdownComponent = __decorate([
    Component({
        selector: 'lib-dropdown',
        template: `
  <div class="dropdown" [style.width]="dropdownWidth +'px'">
  <div
    class="select-border-bottom text-dark-blue fs-14 ff-montserrat  d-flex justify-content-between align-items-center  cursor-pointer"
    (click)="dropdownShow();preventCloseOnClick()">
    <div class="fw-bold" [title]="dropdownSelect">{{dropdownSelect | dropdownFideInfo}}</div>
    <div><i class="fas fa-caret-down fs-14 ms-2"></i></div>
  </div>
  <div class="dropdown-style shadow rounded w-100 py-2" [style.width]="dropdownWidth + 'px'" *ngIf="sCurveDropdown">
    <div class="options text-dark-blue fs-13 ff-montserrat" *ngFor="let selectItem of dropdownList"
      [ngClass]="selectItem == dropdownSelect ? 'selected-dropdown':''"
      (click)="unitNameSelect(selectItem);preventCloseOnClick()">
      {{selectItem}}</div>
  </div>
</div>
  `,
        styles: [`

.dropdown{
  display: inline-block;
}
.dropdown-style{
  position: absolute;
  // right: 0px;
  z-index: 10 !important;
  background-color: white !important;
  margin-top: 2px;
  max-height: 250px;
  overflow-y: auto;
}
.dropdown-style::-webkit-scrollbar{
  width: 2px;
}
.cursor-pointer{
  cursor: pointer;
}
.options{
  padding: 0px 10px;
  cursor: pointer;
  white-space: nowrap;
}
.selected-dropdown{
  background-color: #D2F0FF;
}
.options:hover{
  background-color: #D2F0FF;
}
.select-border-bottom {
  border-bottom: 1.5px solid #EEEEEE;
}
.text-dark-blue{
  color: #1E3044;
}
.fs-13{
  font-size: 13px;
}
.fs-14{
  font-size: 14px;
}
// .ff-montserrat{
  // font-family: 'am-Montserrat';
  /* font-weight: 800; */
// }
.w-150px{
  width: 150px;
}
.fw-bold{
  font-weight: 800 !important;
}
.opacity50{
  opacity: 0.5;
}

  `]
    })
], DropdownComponent);
let DropdownHideInfoPipe = class DropdownHideInfoPipe {
    transform(value, ...args) {
        if (value) {
            let val = value + '';
            if (val && val.length >= 15) {
                val = val.slice(0, 14) + "...";
            }
            return val;
        }
        else {
            return '';
        }
    }
};
DropdownHideInfoPipe = __decorate([
    Pipe({
        name: 'dropdownFideInfo',
        pure: true,
    })
], DropdownHideInfoPipe);

let DropdownModule = class DropdownModule {
};
DropdownModule = __decorate([
    NgModule({
        declarations: [DropdownComponent, DropdownHideInfoPipe],
        imports: [
            CommonModule
        ],
        exports: [DropdownComponent]
    })
], DropdownModule);

/*
 * Public API Surface of dropdown
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DropdownComponent, DropdownHideInfoPipe, DropdownModule, DropdownService };
//# sourceMappingURL=vikas-detect-dropdown.js.map
